searchData={"items":[{"type":"task","title":"mix kyopuro.login","doc":"AtCoderにログインするMixタスクです。\n\n    $ mix kyopuro.login\n\n認証情報はプロンプトから入力、もしくはConfigから取得させることができます。\n\nConfigから認証情報を取得させる場合は以下のように記載してください。パスワードはファイルに保存したくない場合は`username`のみを記載してください。\n\n```elixir\n# in config/config.exs\nimport Config\n\nconfig :kyopuro,\n  username: \"hogehoge\",\n  password: \"hugahuga\"\n```\n\nConfigから認証情報を取得できない場合はプロンプトから入力を求められます。\n\nログインに失敗した趣旨のメッセージが表示された場合は、認証情報を確認の上再度実行してください。","ref":"Mix.Tasks.Kyopuro.Login.html"},{"type":"task","title":"mix kyopuro.new","doc":"コンテスト/問題を指定してモジュールとテストを生成するMixタスクです。本Mixタスクを使用する場合は事前に`mix kyopuro.login`を実行してログインしておくことが必要です。\n\n    $ mix kyopuro.new\n\n上記Mixタスクを実行するとコンテストを「常設中のコンテスト」「Rated対象から検索」「カテゴリから検索」「キーワードから検索」から検索するよう促されます。\n\n    1. URLを入力\n    2. 常設中のコンテスト\n    3. Rated対象から検索\n    4. カテゴリから検索\n    5. キーワードから検索\n\n    >\n\n適当に選択していくとモジュールとテストが生成されます。例としてhogeプロジェクトでABC100のA問題を選択したものを載せます。\n\n```\n┬ lib - hoge - abc100 - a.ex\n│\n└ test - hoge_test - abc100 - a_test.exs\n```\n\nモジュールとテストはKyopuroで用意しているテンプレート以外にユーザー側で定義したものを使用することが可能です。\n\n```elixir\n# in config/config.exs\nimport Config\n\nconfig :kyopuro,\n  module_template: \"priv/templates/module_template.ex\",\n  test_template: \"priv/templates/test_template.ex\"\n```\n\nKyopuroで用意しているテンプレートは以下のようになっています。\n\n<!-- tabs-open -->\n\n#","ref":"Mix.Tasks.Kyopuro.New.html"},{"type":"task","title":"モジュールのテンプレート - mix kyopuro.new","doc":"```elixir\n# モジュールのテンプレート\ndefmodule <%= inspect(module) %> do\n  def main do\n\n  end\nend\n```\n\n#","ref":"Mix.Tasks.Kyopuro.New.html#module-%E3%83%A2%E3%82%B8%E3%83%A5%E3%83%BC%E3%83%AB%E3%81%AE%E3%83%86%E3%83%B3%E3%83%97%E3%83%AC%E3%83%BC%E3%83%88"},{"type":"task","title":"テストのテンプレート - mix kyopuro.new","doc":"```erlang\ndefmodule <%= inspect(test_module) %> do\n  use ExUnit.Case\n\n  import ExUnit.CaptureIO\n<%= for test_case <- test_cases do %>\n  test <%= inspect(Keyword.get(test_case, :input)) %> do\n    assert(\n      capture_io([input: <%= inspect(Keyword.get(test_case, :input)) %>, capture_prompt: false], fn ->\n        <%= inspect(module) %>.main()\n      end) == <%= inspect(Keyword.get(test_case, :output)) %>\n    )\n  end<% end %>\nend\n```\n\n<!-- tabs-close -->","ref":"Mix.Tasks.Kyopuro.New.html#module-%E3%83%86%E3%82%B9%E3%83%88%E3%81%AE%E3%83%86%E3%83%B3%E3%83%97%E3%83%AC%E3%83%BC%E3%83%88"},{"type":"task","title":"mix kyopuro.submit","doc":"提出するMixタスクです。本Mixタスクを使用する場合は事前に`mix kyopuro.login`を実行してログインしておくことが必要です。\n\n提出したいファイルのパスを指定することで提出できます。例としてABC100のA問題を提出するコマンドは以下のようになります。\n\n    $ mix kyopuro.submit lib/hoge/abc_001/a.ex\n\n複数提出したい場合は連続してファイルのパスを指定することで提出できます。\n\n    $ mix kyopuro.submit lib/hoge/abc_001/a.ex lib/hoge/abc_001/b.ex\n\nまとめて提出したい場合はファイルのパスを途中まで指定することで提出できます。\n\n    $ mix kyopuro.submit lib/hoge/abc_001\n\n> ##","ref":"Mix.Tasks.Kyopuro.Submit.html"},{"type":"task","title":"注意事項 {: .error} - mix kyopuro.submit","doc":">\n> 提出に必要な情報は`mix kyopuro.new`を実行したときに生成される`mapping`が持っているため、そこに記載のないファイルのパスを指定しても提出されません。手動で作成したモジュールを提出したい場合は`mapping`を手動で編集してください。","ref":"Mix.Tasks.Kyopuro.Submit.html#module-%E6%B3%A8%E6%84%8F%E4%BA%8B%E9%A0%85-error"},{"type":"extras","title":"Kyopuro","doc":"# Kyopuro\n\nAtCoder用のmixタスクを提供するパッケージです。このパッケージはモジュールの生成とテストケースの生成、提出を行うmixタスクを提供します。\n\n---","ref":"readme.html"},{"type":"extras","title":"インストール - Kyopuro","doc":"`deps`への追加と`mix deps.get`を実行してください。\n\n```elixir\ndef deps do\n  [\n    {:kyopuro, \"~> 0.6.0\"}\n  ]\nend\n```\n\n---","ref":"readme.html#%E3%82%A4%E3%83%B3%E3%82%B9%E3%83%88%E3%83%BC%E3%83%AB"},{"type":"extras","title":"使い方 - Kyopuro","doc":"過去バージョンでは[AtCoder](https://atcoder.jp/)と[YukiCoder](https://yukicoder.me/)に対応していましたが、現バージョンではAtCoderのみ対応しています。","ref":"readme.html#%E4%BD%BF%E3%81%84%E6%96%B9"},{"type":"extras","title":"AtCoder - Kyopuro","doc":"#","ref":"readme.html#atcoder"},{"type":"extras","title":"Login - ログイン - Kyopuro","doc":"最初に`mix kyopuro.login`を実行します。\n\n    $ mix kyopuro.login\n\n認証情報はプロンプトから入力、もしくはConfigから取得させることができます。\n\nConfigから認証情報を取得させる場合は以下のように記載してください。\n\n```elixir\n# in config/config.exs\nimport Config\n\nconfig :kyopuro,\n  username: \"hogehoge\",\n  password: \"hugahuga\"\n```\n\nログインに失敗した趣旨のメッセージが表示された場合は、認証情報を確認の上再度実行してください。\n  \n#","ref":"readme.html#login-%E3%83%AD%E3%82%B0%E3%82%A4%E3%83%B3"},{"type":"extras","title":"Generate module & test - モジュールとテストの生成 - Kyopuro","doc":"ログインが完了したら`mix kyopuro.new`を実行してモジュールとテストを生成することができます。\n\n    $ mix kyopuro.new\n\nコマンドを実行すると選択肢が表示されるので指示に従いコンテストと問題を選択してください。\n\nABC100を選択した場合モジュールとテストは以下のように生成されます。\n\n```\n ┬ lib - hoge - abc100 ┬ a.ex\n │                     ├ b.ex\n │                     ├ c.ex\n │                     └ d.ex\n │\n └ test - hoge_test - abc100 ┬ a_test.exs\n                             ├ b_test.exs\n                             ├ c_test.exs\n                             └ d_test.exs\n```\n\n#","ref":"readme.html#generate-module-test-%E3%83%A2%E3%82%B8%E3%83%A5%E3%83%BC%E3%83%AB%E3%81%A8%E3%83%86%E3%82%B9%E3%83%88%E3%81%AE%E7%94%9F%E6%88%90"},{"type":"extras","title":"Running Tests - テストの実行 - Kyopuro","doc":"テストを実行するには`mix test <ファイルパス>`を使用します。\n\n例としてABC100のA問題のテストを実施するには以下のようなコマンドになります。\n\n    $ mix test test/hoge_test/abc100/a_test.exs\n\n#","ref":"readme.html#running-tests-%E3%83%86%E3%82%B9%E3%83%88%E3%81%AE%E5%AE%9F%E8%A1%8C"},{"type":"extras","title":"Submit - 提出 - Kyopuro","doc":"提出するには`mix kyopuro.submit <ファイルパス>`を使用します。\n\n例としてABC100のA問題を提出するコマンドは以下のようになります。\n\n    $ mix kyopuro.submit lib/hoge/abc001/a.ex\n\n複数提出したい場合は連続してファイルパスを指定することで提出できます。\n\n    $ mix kyopuro.submit lib/hoge/abc001/a.ex lib/hoge/abc001/b.ex\n\nファイルパスは単なる前方一致なので、以下のように指定すればlib/hoge/abc001配下のファイルをすべて提出することができます。\n\n    $ mix kyopuro.submit lib/hoge/abc001\n\n> ##","ref":"readme.html#submit-%E6%8F%90%E5%87%BA"},{"type":"extras","title":"注意事項 {: .error} - Kyopuro","doc":">\n> 提出に必要な情報は`mix kyopuro.new`を実行したときに生成される`mapping`が持っているため、そこに記載のないファイルのパスを指定しても提出されません。手動で作成したモジュールを提出したい場合は`mapping`を手動で編集してください。\n\n#","ref":"readme.html#%E6%B3%A8%E6%84%8F%E4%BA%8B%E9%A0%85-error"},{"type":"extras","title":"Template - テンプレート - Kyopuro","doc":"生成するモジュールやテストコードのテンプレートをカスタマイズすることができます。必要な\n\n```elixir\n# in config/config.exs\nimport Config\n\nconfig :kyopuro,\n    module_template: \"#{module_template_file_path}\"\n```","ref":"readme.html#template-%E3%83%86%E3%83%B3%E3%83%97%E3%83%AC%E3%83%BC%E3%83%88"},{"type":"extras","title":"コントリビュート - Kyopuro","doc":"適当にIssueを立てていただいたり、PRを作成していただいて構いません。","ref":"readme.html#%E3%82%B3%E3%83%B3%E3%83%88%E3%83%AA%E3%83%93%E3%83%A5%E3%83%BC%E3%83%88"}],"content_type":"text/markdown"}